package de.intevation.flys.importer;

import java.math.BigDecimal;
import java.sql.SQLException;
import java.util.List;

import org.apache.log4j.Logger;

import org.hibernate.Session;
import org.hibernate.Query;
import org.hibernate.exception.ConstraintViolationException;

import de.intevation.flys.model.DischargeZone;
import de.intevation.flys.model.NamedMainValue;
import de.intevation.flys.model.River;


public class ImportDischargeZone {

    private static final Logger log =
        Logger.getLogger(ImportDischargeZone.class);


    private String gaugeName;

    private ImportNamedMainValue mainValue;

    private BigDecimal lowerFactor;

    private BigDecimal upperFactor;

    private DischargeZone peer;


    public ImportDischargeZone(
        ImportNamedMainValue mainValue,
        String               gaugeName,
        BigDecimal           lowerFactor,
        BigDecimal           upperFactor
    ) {
        this.mainValue   = mainValue;
        this.gaugeName   = gaugeName;
        this.lowerFactor = lowerFactor;
        this.upperFactor = upperFactor;
    }


    public void storeDependencies(River river)
    throws SQLException, ConstraintViolationException
    {
        log.debug("store dependencies");

        mainValue.getPeer();

        getPeer(river);
    }


    public DischargeZone getPeer(River river) {
        if (peer == null) {
            Session session = ImporterSession.getInstance().getDatabaseSession();

            NamedMainValue namedMainValue = mainValue.getPeer();

            Query query = session.createQuery(
                "from DischargeZone where " +
                "   river:=river and " +
                "   gaugeName=:gaugeName and " +
                "   mainValue=:mainValue"
            );

            query.setParameter("river", river);
            query.setParameter("gaugeName", gaugeName);
            query.setParameter("mainValue", namedMainValue);

            List<DischargeZone> zone = query.list();

            if (zone.isEmpty()) {
                peer = new DischargeZone(
                    gaugeName,
                    river,
                    namedMainValue,
                    lowerFactor,
                    upperFactor);

                session.save(peer);
            }
            else {
                peer = zone.get(0);
            }
        }

        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
